Stan Math Library: Eigen Namespace Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

Namespaces | Classes
Eigen Namespace Reference

(Expert) Numerical traits for algorithmic differentiation variables. More...

## Namespaces
| internal
| (Expert) Product traits for algorithmic differentiation variables.

## Classes
struct | NumTraits< stan::math::fvar< T > >
| Numerical traits template override for Eigen for automatic gradient variables. More...
struct | NumTraits< stan::math::var >
| Numerical traits template override for Eigen for automatic gradient variables. More...

## Detailed Description

(Expert) Numerical traits for algorithmic differentiation variables.

[ Stan Home Page ] © 2011–2016, Stan Development Team.